0.9.9 API documentation: quaternion.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
gtc/quaternion.hpp File Reference

GLM_GTC_quaternion More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | eulerAngles (qua< T, Q > const &x)
| Returns euler angles, pitch as x, yaw as y, roll as z. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | greaterThan (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison of result x > y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | greaterThanEqual (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison of result x >= y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | lessThan (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison result of x < y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | lessThanEqual (qua< T, Q > const &x, qua< T, Q > const &y)
| Returns the component-wise comparison of result x <= y. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | mat3_cast (qua< T, Q > const &x)
| Converts a quaternion to a 3 * 3 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | mat4_cast (qua< T, Q > const &x)
| Converts a quaternion to a 4 * 4 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | pitch (qua< T, Q > const &x)
| Returns pitch value of euler angles expressed in radians. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | quat_cast (mat< 3, 3, T, Q > const &x)
| Converts a pure rotation 3 * 3 matrix to a quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | quat_cast (mat< 4, 4, T, Q > const &x)
| Converts a pure rotation 4 * 4 matrix to a quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | quatLookAt (vec< 3, T, Q > const &direction, vec< 3, T, Q > const &up)
| Build a look at quaternion based on the default handedness. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | quatLookAtLH (vec< 3, T, Q > const &direction, vec< 3, T, Q > const &up)
| Build a left-handed look at quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | quatLookAtRH (vec< 3, T, Q > const &direction, vec< 3, T, Q > const &up)
| Build a right-handed look at quaternion. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | roll (qua< T, Q > const &x)
| Returns roll value of euler angles expressed in radians. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL T | yaw (qua< T, Q > const &x)
| Returns yaw value of euler angles expressed in radians. More...

## Detailed Description

GLM_GTC_quaternion

See also
  Core features (dependence)
  GLM_GTC_constants (dependence)

Definition in file gtc/quaternion.hpp.